package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.Order;

/**
 * 服务订单Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IOrderService 
{
    /**
     * 查询服务订单
     * 
     * @param id 服务订单主键
     * @return 服务订单
     */
    public Order selectOrderById(Long id);



    public Order selectOrderByOrderId(String orderId);
    /**
     * 查询服务订单列表
     * 
     * @param order 服务订单
     * @return 服务订单集合
     */
    public List<Order> selectOrderList(Order order);

    /**
     * 新增服务订单
     * 
     * @param order 服务订单
     * @return 结果
     */
    public int insertOrder(Order order);

    /**
     * 修改服务订单
     * 
     * @param order 服务订单
     * @return 结果
     */
    public int updateOrder(Order order);

    /**
     * 批量删除服务订单
     * 
     * @param ids 需要删除的服务订单主键集合
     * @return 结果
     */
    public int deleteOrderByIds(Long[] ids);

    /**
     * 删除服务订单信息
     * 
     * @param id 服务订单主键
     * @return 结果
     */
    public int deleteOrderById(Long id);
}
